@@ -6,18 +6,6 @@ from airflow.models import Connection
 from airflow_tm1.hooks.tm1 import TM1Hook
 
 
-def test_hook_init():
-    conn = Connection(
-        conn_id="tm1_default",
-        host="localhost",
-        login="admin",
-        password="apple",
-        port=10001,
-        extra="""{"ssl":false}""",
-    )
-
-
-
 class TestTM1Hook(unittest.TestCase):
     @classmethod
     def setUpClass(cls):
